/**
@license
Copyright (c) 2022 trading_peter
This program is available under Apache License Version 2.0
*/

import '../../tp-logic-canvas.js';
import './simple-block.js';
import { LitElement, html, css } from 'lit';

class DemoApp extends LitElement {
  static get styles() {
    return [
      css`
        :host {
          display: block;
          padding: 20px;
        }

        tp-logic-canvas {
          width: 1200px;
          height: 800px;
          background: #040a13;
        }
      `
    ];
  }

  render() {
    const { blocks, connections } = this;

    return html`
      <tp-logic-canvas .connections=${connections}>
        ${blocks.map(block => this.renderBlock(block))}
      </tp-logic-canvas>
    `;
  }

  renderBlock(block) {
    switch (block.type) {
      case 'simple-block':
        return html`
          <simple-block .title=${block.id} .left=${block.left} .top=${block.top} .inputs=${block.inputs} .outputs=${block.outputs}></simple-block>
        `;
    }
  }

  static get properties() {
    return {
      blocks: { type: Array },
      connections: { type: Array },
    };
  }

  constructor() {
    super();

    this.blocks = [
      {
        id: 'block1',
        type: 'simple-block',
        left: 200,
        top: 200,
        inputs: [
          { name: 'inputA' },
          { name: 'inputB' }
        ],
      },
      {
        id: 'block2',
        type: 'simple-block',
        left: 40,
        top: 40,
        outputs: [
          { name: 'outputA' },
        ],
      }
    ];

    this.connections = [
      { srcBlock: 'block2', srcOutput: 'outputA', destBlock: 'block1', destInput: 'inputB' }
    ]
  }
}

window.customElements.define('demo-app', DemoApp);
